/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
 *
 * @author Stefan Eckert <stefan.eckert@open-xchange.com>
 */

define('io.ox/office/settings/contexttemplatemodel', function () {

    'use strict';

    function Model(data) {

        /**
         * returns all template folder-ids in one array
         */
        this.getAll = _.constant(data);

        this.add = _.noop;

        this.remove = _.noop;
    }

    return Model;

});
